The yt Astrophysical Analysis Extension
=======================================

This is ``yt_astro_analysis``, the `yt <https://github.com/yt-project/yt>`_
extension package for astrophysical analysis.  This is primarily machinery that
used to be in yt's analysis_modules.  These were made into a separate package to
allow yt to become less astro-specifc and to allow these modules to be developed
on their own schedule.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Installation
   Importing
   Modules
   cookbook/index
   Contributing
   Help
   reference
